@@ -1,3 +1,8 @@
+# Dailies
+class DailyAlreadyCompleted(Exception):
+    pass
+class DailyNotActive(Exception):
+    pass
 
 # General
 class ParseException(Exception):
@@ -51,3 +56,5 @@ class AccountFrozen(Exception):
 
 class NoActiveNeopet(Exception):
     pass
+class UserLoggedOut(Exception):
+    pass
