@@ -1,5 +1,6 @@
 from collections import UserList
 
+from neolib.Exceptions import ParseException
 from neolib.NeolibBase import NeolibBase
 from neolib.shop.Transaction import Transaction
 
@@ -31,20 +32,24 @@ class History(NeolibBase, UserList):
         # Load the history page
         pg = self._get_page('sales')
 
-        rows = self._xpath('rows', pg)
-        rows.pop(0)
-        rows.pop()
+        try:
+            rows = self._xpath('rows', pg)
+            rows.pop(0)
+            rows.pop()
 
-        for row in rows:
-            trans = Transaction()
-            details = self._xpath('details', row)
+            for row in rows:
+                trans = Transaction()
+                details = self._xpath('details', row)
 
-            trans.date = details[0].text_content()
-            trans.item = details[1].text_content()
-            trans.buyer = details[2].text_content()
-            trans.price = int(self._remove_multi(details[3].text_content(), [',', ' NP']))
+                trans.date = details[0].text_content()
+                trans.item = details[1].text_content()
+                trans.buyer = details[2].text_content()
+                trans.price = int(self._remove_multi(details[3].text_content(), [',', ' NP']))
 
-            self.data.append(trans)
+                self.data.append(trans)
+        except Exception:
+            self._logger.exception('Failed to parse shop history', {'pg': pg})
+            raise ParseException('Failed to parse shop history')
 
     def __repr__(self):
         return 'Sales History <' + str(len(self.data)) + ' Transactions>'
