@@ -152,7 +152,8 @@ class UserBackShop(NeolibBase):
                 items = self.inventory.find(pg=pg_num)
                 data = self._build_data(items, pg_num)
 
-                pg = self._get_page('update', post_data=data)
+                pg = self._get_page('update', post_data=data,
+                                    header_values={'Referer': self._urls['index']})
 
                 if 'red_oops.gif' in pg.content:
                     self._logger.error('Failed to update user shop', {'pg': pg})
